@@ -34,7 +34,7 @@ THE SOFTWARE.
 #include "OgreResourceManager.h"
 #include "OgreTexture.h"
 #include "OgreSingleton.h"
-
+#include "OgreTextureUnitState.h"
 
 namespace Ogre {
 
@@ -64,19 +64,25 @@ namespace Ogre {
         TextureManager(void);
         virtual ~TextureManager();
 
+        /// create a new sampler
+        SamplerPtr createSampler(const String& name = BLANKSTRING);
+
+        /// retrieve an named sampler
+        const SamplerPtr& getSampler(const String& name) const;
 
         /// Create a new texture
-        /// @see ResourceManager::createResource
+        /// @copydetails ResourceManager::createResource
         TexturePtr create (const String& name, const String& group,
                             bool isManual = false, ManualResourceLoader* loader = 0,
                             const NameValuePairList* createParams = 0);
-        /// Get a resource by name
-        /// @see ResourceManager::getResourceByName
+        /// @copydoc ResourceManager::getResourceByName
         TexturePtr getByName(const String& name, const String& groupName OGRE_RESOURCE_GROUP_INIT);
 
         using ResourceManager::createOrRetrieve;
 
         /** @overload createOrRetrieve
+            
+            @copydetails ResourceManager::createResource
 
             @param
                 texType The type of texture to load/create, defaults to normal 2D textures
@@ -88,9 +94,7 @@ namespace Ogre {
             @param
                 gamma The gamma adjustment factor to apply to this texture (brightening/darkening)
             @param 
-                isAlpha Only applicable to greyscale images. If true, specifies that
-                the image should be loaded into an alpha texture rather than a
-                single channel colour texture - useful for fixed-function systems.
+                isAlpha deprecated: same as specifying #PF_A8 for @c desiredFormat
             @param 
                 desiredFormat The format you would like to have used instead of
                 the format being based on the contents of the texture
@@ -103,40 +107,17 @@ namespace Ogre {
         ResourceCreateOrRetrieveResult createOrRetrieve(
             const String &name, const String& group, bool isManual,
             ManualResourceLoader* loader, const NameValuePairList* createParams,
-            TextureType texType = TEX_TYPE_2D, int numMipmaps = MIP_DEFAULT, 
+            TextureType texType, int numMipmaps = MIP_DEFAULT,
             Real gamma = 1.0f, bool isAlpha = false,
             PixelFormat desiredFormat = PF_UNKNOWN, bool hwGammaCorrection = false);
 
         /** Prepares to loads a texture from a file.
-            @param
-                name The file to load, or a String identifier in some cases
-            @param
-                group The name of the resource group to assign the texture to
-            @param
-                texType The type of texture to load/create, defaults to normal 2D textures
-            @param
-                numMipmaps The number of pre-filtered mipmaps to generate. If left to MIP_DEFAULT then
-                the TextureManager's default number of mipmaps will be used (see setDefaultNumMipmaps())
-                If set to MIP_UNLIMITED mipmaps will be generated until the lowest possible
-                level, 1x1x1.
-            @param
-                gamma The gamma adjustment factor to apply to this texture (brightening/darkening)
-            @param 
-                isAlpha Only applicable to greyscale images. If true, specifies that
-                the image should be loaded into an alpha texture rather than a
-                single channel colour texture - useful for fixed-function systems.
-            @param 
-                desiredFormat The format you would like to have used instead of
-                the format being based on the contents of the texture
-            @param hwGammaCorrection Pass 'true' to enable hardware gamma correction
-                (sRGB) on this texture. The hardware will convert from gamma space
-                to linear space when reading from this texture. Only applicable for 
-                8-bits per channel textures, will be ignored for other types. Has the advantage
-                over pre-applied gamma that the texture precision is maintained.
+            @copydetails TextureManager::load
+            @param isAlpha deprecated: same as specifying #PF_A8 for @c desiredFormat
         */
         TexturePtr prepare(
-            const String& name, const String& group, 
-            TextureType texType = TEX_TYPE_2D, int numMipmaps = MIP_DEFAULT, 
+            const String& name, const String& group,
+            TextureType texType = TEX_TYPE_2D, int numMipmaps = MIP_DEFAULT,
             Real gamma = 1.0f, bool isAlpha = false,
             PixelFormat desiredFormat = PF_UNKNOWN, bool hwGammaCorrection = false);
 
@@ -154,58 +135,33 @@ namespace Ogre {
                 level, 1x1x1.
             @param
                 gamma The gamma adjustment factor to apply to this texture (brightening/darkening)
-                    during loading
-            @param 
-                isAlpha Only applicable to greyscale images. If true, specifies that
-                the image should be loaded into an alpha texture rather than a
-                single channel colour texture - useful for fixed-function systems.
+
             @param 
                 desiredFormat The format you would like to have used instead of
-                the format being based on the contents of the texture. Pass PF_UNKNOWN
-                to default.
-            @param hwGammaCorrection Pass 'true' to enable hardware gamma correction
+                the format being based on the contents of the texture; the manager reserves
+                the right to create a different format for the texture if the 
+                original format is not available in this context.
+            @param hwGammaCorrection pass 'true' to enable hardware gamma correction
                 (sRGB) on this texture. The hardware will convert from gamma space
                 to linear space when reading from this texture. Only applicable for 
                 8-bits per channel textures, will be ignored for other types. Has the advantage
                 over pre-applied gamma that the texture precision is maintained.
         */
-        TexturePtr load(
-            const String& name, const String& group, 
-            TextureType texType = TEX_TYPE_2D, int numMipmaps = MIP_DEFAULT, 
-            Real gamma = 1.0f, bool isAlpha = false,
-            PixelFormat desiredFormat = PF_UNKNOWN, 
-            bool hwGammaCorrection = false);
+        TexturePtr load(const String& name, const String& group, TextureType texType = TEX_TYPE_2D,
+                        int numMipmaps = MIP_DEFAULT, Real gamma = 1.0f,
+                        PixelFormat desiredFormat = PF_UNKNOWN, bool hwGammaCorrection = false);
+        /// @deprecated
+        OGRE_DEPRECATED TexturePtr load(const String& name, const String& group, TextureType texType,
+                                        int numMipmaps, Real gamma, bool isAlpha,
+                                        PixelFormat desiredFormat = PF_UNKNOWN,
+                                        bool hwGammaCorrection = false);
 
         /** Loads a texture from an Image object.
             @note
                 The texture will create as manual texture without loader.
-            @param
-                name The name to give the resulting texture
-            @param
-                group The name of the resource group to assign the texture to
+            @copydetails TextureManager::prepare
             @param
                 img The Image object which contains the data to load
-            @param
-                texType The type of texture to load/create, defaults to normal 2D textures
-            @param
-                numMipmaps The number of pre-filtered mipmaps to generate. If left to MIP_DEFAULT then
-                the TextureManager's default number of mipmaps will be used (see setDefaultNumMipmaps())
-                If set to MIP_UNLIMITED mipmaps will be generated until the lowest possible
-                level, 1x1x1.
-            @param
-                gamma The gamma adjustment factor to apply to this texture (brightening/darkening)
-            @param 
-                isAlpha Only applicable to greyscale images. If true, specifies that
-                the image should be loaded into an alpha texture rather than a
-                single channel colour texture - useful for fixed-function systems.
-            @param 
-                desiredFormat The format you would like to have used instead of
-                the format being based on the contents of the texture
-            @param hwGammaCorrection Pass 'true' to enable hardware gamma correction
-                (sRGB) on this texture. The hardware will convert from gamma space
-                to linear space when reading from this texture. Only applicable for 
-                8-bits per channel textures, will be ignored for other types. Has the advantage
-                over pre-applied gamma that the texture precision is maintained.
         */
         virtual TexturePtr loadImage( 
             const String &name, const String& group, const Image &img, 
@@ -296,6 +252,7 @@ namespace Ogre {
             @param fsaa The level of multisampling to use if this is a render target. Ignored
                 if usage does not include TU_RENDERTARGET or if the device does
                 not support it.
+            @param fsaaHint specify "Quality" to enable CSAA on D3D
         */
         virtual TexturePtr createManual(const String & name, const String& group,
             TextureType texType, uint width, uint height, uint depth, 
@@ -420,7 +377,7 @@ namespace Ogre {
         @return true if the texture filtering is supported.
         */
         virtual bool isHardwareFilteringSupported(TextureType ttype, PixelFormat format, int usage,
-            bool preciseFormatOnly = false) = 0;
+            bool preciseFormatOnly = false);
 
         /** Sets the default number of mipmaps to be used for loaded textures, for when textures are
             loaded automatically (e.g. by Material class) or when 'load' is called with the default
@@ -442,6 +399,9 @@ namespace Ogre {
         /// Internal method to create a warning texture (bound when a texture unit is blank)
         const TexturePtr& _getWarningTexture();
 
+        /// get the default sampler
+        const SamplerPtr& getDefaultSampler();
+
         /// @copydoc Singleton::getSingleton()
         static TextureManager& getSingleton(void);
         /// @copydoc Singleton::getSingleton()
@@ -449,17 +409,48 @@ namespace Ogre {
 
     protected:
 
+        virtual SamplerPtr _createSamplerImpl() { return std::make_shared<Sampler>(); }
+
         ushort mPreferredIntegerBitDepth;
         ushort mPreferredFloatBitDepth;
         uint32 mDefaultNumMipmaps;
-#if !OGRE_USE_STD11 && OGRE_COMPILER == OGRE_COMPILER_MSVC
-#pragma warning ( push )
-#pragma warning ( disable: 4251 )
-#endif
         TexturePtr mWarningTexture;
-#if !OGRE_USE_STD11 && OGRE_COMPILER == OGRE_COMPILER_MSVC
-#pragma warning ( pop )
-#endif
+        SamplerPtr mDefaultSampler;
+        std::map<String, SamplerPtr> mNamedSamplers;
+    };
+
+    /// Specialisation of TextureManager for offline processing. Cannot be used with an active RenderSystem.
+    class _OgreExport DefaultTextureManager : public TextureManager
+    {
+        /// noop implementation
+        class NullTexture : public Texture
+        {
+        public:
+            NullTexture(ResourceManager* creator, const String& name, ResourceHandle handle,
+                        const String& group)
+                : Texture(creator, name, handle, group)
+            {
+            }
+            const HardwarePixelBufferSharedPtr& getBuffer(size_t, size_t) override
+            {
+                static HardwarePixelBufferSharedPtr nullBuffer;
+                return nullBuffer;
+            }
+
+        protected:
+            void createInternalResourcesImpl() override {}
+            void freeInternalResourcesImpl() override {}
+            void loadImpl() override {}
+        };
+    public:
+        bool isHardwareFilteringSupported(TextureType, PixelFormat, int, bool) override { return false; }
+        PixelFormat getNativeFormat(TextureType, PixelFormat, int) override { return PF_UNKNOWN; }
+
+        Resource* createImpl(const String& name, ResourceHandle handle, const String& group, bool,
+                             ManualResourceLoader*, const NameValuePairList*) override
+        {
+            return new NullTexture(this, name, handle, group);
+        }
     };
     /** @} */
     /** @} */
