@@ -1359,17 +1359,20 @@ namespace Ogre
         */
         uint8 getBlendTextureIndex(uint8 layerIndex) const;
 
-        /// Get the number of blend textures in use
-        uint8 getBlendTextureCount() const;
+        /// @deprecated use getBlendTextures()
+        OGRE_DEPRECATED uint8 getBlendTextureCount() const;
         /// Get the number of blend textures needed for a given number of layers
-        uint8 getBlendTextureCount(uint8 numLayers) const;
+        static uint8 getBlendTextureCount(uint8 numLayers) { return ((numLayers - 2) / 4) + 1; }
 
 
-        /** Get the name of the packed blend texture at a specific index.
-        @param textureIndex This is the blend texture index, not the layer index
+        /** Get the packed blend textures.
+        @note These are indexed by the blend texture index, not the layer index
             (multiple layers will share a blend texture)
         */
-        const String& getBlendTextureName(uint8 textureIndex) const;
+        const std::vector<TexturePtr>& getBlendTextures() const { return mBlendTextureList; }
+
+        /// @deprecated use getBlendTextures()
+        OGRE_DEPRECATED const String& getBlendTextureName(uint8 textureIndex) const;
 
         /** Set whether a global colour map is enabled. 
         @remarks
